Documentation
¶
Index ¶
- type FileChangedMsg
- type LogViewer
- func (lv *LogViewer) Init() tea.Cmd
- func (lv *LogViewer) Refresh()
- func (lv *LogViewer) SetLogPath(path string)
- func (lv *LogViewer) SetSize(width, height int)
- func (lv *LogViewer) StartWatching() tea.Cmd
- func (lv *LogViewer) StopWatching()
- func (lv *LogViewer) Update(msg tea.Msg) (*LogViewer, tea.Cmd)
- func (lv *LogViewer) View() string
- type ProgressBar
- func (pb *ProgressBar) GetPercentage() float64
- func (pb *ProgressBar) GetProgress() (current, total int64, message string)
- func (pb *ProgressBar) Increment(n int64)
- func (pb *ProgressBar) Reset()
- func (pb *ProgressBar) SetCurrent(current int64)
- func (pb *ProgressBar) SetMessage(message string)
- func (pb *ProgressBar) SetSize(width int)
- func (pb *ProgressBar) SetStatus(status string, healthy bool)
- func (pb *ProgressBar) SetStepMessage(message string, progress int64)
- func (pb *ProgressBar) SetTotal(total int64)
- func (pb *ProgressBar) View() string
- type Tabs
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type FileChangedMsg ¶
type FileChangedMsg struct {
Path string
}
FileChangedMsg indicates a log file has been modified.
type LogViewer ¶
type LogViewer struct {
// contains filtered or unexported fields
}
LogViewer displays log files with automatic file watching.
func (*LogViewer) SetLogPath ¶
SetLogPath sets the log file path and starts watching it.
func (*LogViewer) StartWatching ¶
StartWatching begins watching the current log file for changes.
func (*LogViewer) StopWatching ¶
func (lv *LogViewer) StopWatching()
StopWatching stops watching the current log file.
type ProgressBar ¶
type ProgressBar struct {
// contains filtered or unexported fields
}
ProgressBar represents a simple progress bar.
func NewProgressBar ¶
func NewProgressBar(total int64, title string) *ProgressBar
NewProgressBar creates a new progress bar component.
func (*ProgressBar) GetPercentage ¶
func (pb *ProgressBar) GetPercentage() float64
GetPercentage returns the current percentage.
func (*ProgressBar) GetProgress ¶
func (pb *ProgressBar) GetProgress() (current, total int64, message string)
GetProgress returns the current progress values.
func (*ProgressBar) Increment ¶
func (pb *ProgressBar) Increment(n int64)
Increment adds to the current progress value.
func (*ProgressBar) Reset ¶
func (pb *ProgressBar) Reset()
Reset prepares the bar for a new operation.
func (*ProgressBar) SetCurrent ¶
func (pb *ProgressBar) SetCurrent(current int64)
SetCurrent sets the current progress value.
func (*ProgressBar) SetMessage ¶
func (pb *ProgressBar) SetMessage(message string)
SetMessage sets the overall progress message.
func (*ProgressBar) SetSize ¶
func (pb *ProgressBar) SetSize(width int)
SetSize sets the progress bar width.
func (*ProgressBar) SetStatus ¶
func (pb *ProgressBar) SetStatus(status string, healthy bool)
SetStatus updates the progress bar status.
func (*ProgressBar) SetStepMessage ¶
func (pb *ProgressBar) SetStepMessage(message string, progress int64)
SetStepMessage sets the current step message and updates progress.
func (*ProgressBar) SetTotal ¶
func (pb *ProgressBar) SetTotal(total int64)
SetTotal sets the total progress value.